@@ -1,3 +1,19 @@
+/*
+ * Copyright (C) 2015 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -159,7 +175,7 @@ bool snappy_udev_setup_required(const char *appname) {
       "   \"/dev/**\""             "\n"
       " ],"                        "\n"
       " \"read_path\": ["          "\n"
-      "   \"/run/dev/data/*\""     "\n"
+      "   \"/run/udev/data/*\""     "\n"
       " ]\n"
       "}";
    debug("looking for: '%s'", needle);
